@@ -6,10 +6,15 @@ use warnings;
 use vars qw($VERSION);
 use base qw/DBIx::Class::Componentised Class::Accessor::Grouped/;
 
+
 sub mk_classdata { 
-    my $self = shift;
-    $self->mk_group_accessors('inherited', $_[0]); 
-    $self->set_inherited(@_) if @_ > 1;
+  shift->mk_classaccessor(@_);
+}
+
+sub mk_classaccessor {
+  my $self = shift;
+  $self->mk_group_accessors('inherited', $_[0]); 
+  $self->set_inherited(@_) if @_ > 1;
 }
 
 sub component_base_class { 'DBIx::Class' }
@@ -18,7 +23,7 @@ sub component_base_class { 'DBIx::Class' }
 # i.e. first release of 0.XX *must* be 0.XX000. This avoids fBSD ports
 # brain damage and presumably various other packaging systems too
 
-$VERSION = '0.08002';
+$VERSION = '0.08003';
 
 sub MODIFY_CODE_ATTRIBUTES {
   my ($class,$code,@attrs) = @_;
@@ -146,14 +151,16 @@ support for SQLite, MySQL, PostgreSQL, Oracle, SQL Server and DB2 and is
 known to be used in production on at least the first four, and is fork-
 and thread-safe out of the box (although your DBD may not be).
 
-This project is still under rapid development, so features added in the
-latest major release may not work 100% yet -- check the Changes if you run
-into trouble, and beware of anything explicitly marked EXPERIMENTAL. Failing
-test cases are *always* welcome and point releases are put out rapidly as
-bugs are found and fixed.
+This project is still under rapid development, so large new features may be
+marked EXPERIMENTAL - such APIs are still usable but may have edge bugs.
+Failing test cases are *always* welcome and point releases are put out rapidly
+as bugs are found and fixed.
+
+We do our best to maintain full backwards compatibility for published
+APIs, since DBIx::Class is used in production in many organisations,
+and even backwards incompatible changes to non-published APIs will be fixed
+if they're reported and doing so doesn't cost the codebase anything.
 
-Even so, we do our best to maintain full backwards compatibility for published
-APIs, since DBIx::Class is used in production in a number of organisations.
 The test suite is quite substantial, and several developer releases are
 generally made to CPAN before the -current branch is merged back to trunk for
 a major release.
@@ -164,8 +171,6 @@ The community can be found via:
 
   SVN: http://dev.catalyst.perl.org/repos/bast/trunk/DBIx-Class/
 
-  Wiki: http://dbix-class.shadowcatsystems.co.uk/
-
   IRC: irc.perl.org#dbix-class
 
 =head1 WHERE TO GO NEXT
@@ -177,6 +182,9 @@ the modules where you will find documentation.
 
 mst: Matt S. Trout <mst@shadowcatsystems.co.uk>
 
+(I mostly consider myself "project founder" these days but the AUTHOR heading
+is traditional :)
+
 =head1 CONTRIBUTORS
 
 abraxxa: Alexander Hartmaier <alex_hartmaier@hotmail.com>
@@ -217,6 +225,8 @@ jesper: Jesper Krogh
 
 jguenther: Justin Guenther <jguenther@cpan.org>
 
+jnapiorkowski: John Napiorkowski <jjn1056@yahoo.com>
+
 jshirley: J. Shirley <jshirley@gmail.com>
 
 konobi: Scott McWhirter
